# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['unlok', 'unlok.api', 'unlok.composition']

package_data = \
{'': ['*']}

install_requires = \
['koil>=0.2.10', 'rath>=0.3.3']

setup_kwargs = {
    'name': 'unlok',
    'version': '0.1.2',
    'description': '',
    'long_description': 'None',
    'author': 'jhnnsrs',
    'author_email': 'jhnnsrs@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
